package com.javielinux.facemix;

import info.Img;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.xmlpull.v1.XmlPullParserException;

import tasks.CropImagesAsyncTask;
import tasks.CropImagesAsyncTask.CropImagesAsyncTaskResponder;
import utils.Utils;
import adapters.ImageAdapter;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnCancelListener;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Menu;
import android.view.MenuItem;
import android.view.Window;
import android.view.WindowManager;
import android.widget.Gallery;
import android.widget.LinearLayout;

import com.android.dataframework.DataFramework;
import com.android.dataframework.Entity;

public class Mix extends Activity implements CropImagesAsyncTaskResponder {
	
	private static final int SHARE_ID = Menu.FIRST;
	private static final int BACK_ID = Menu.FIRST+1;

    private int screen_w = 320;
    private int screen_h = 480;
	
	private List<Integer> mFrozenImages;
	private List<Img> mImages; 
	
	private long mGroupId = 1;
	
	private String mDirFrozenImages = "";
	
	private ProgressDialog progressDialog;
	
	private ArrayList<Gallery> mGalleries = new ArrayList<Gallery>();
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        requestWindowFeature(Window.FEATURE_NO_TITLE);  
        getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN,   
                                WindowManager.LayoutParams.FLAG_FULLSCREEN); 
        
        if (savedInstanceState != null) {
			if (savedInstanceState.containsKey("group")) mGroupId = savedInstanceState.getLong("group");
		} else {
			Bundle extras = getIntent().getExtras();  
			if (extras != null) {
				mGroupId = (extras.containsKey("group")) ? extras.getLong("group") : 1;
			} else {
				mGroupId = 1;
			}
		}
        
        try {
			DataFramework.getInstance().open(this, Utils.appPackage);
		} catch (XmlPullParserException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
        DisplayMetrics dm = this.getResources().getDisplayMetrics();
        screen_w = dm.widthPixels;
        screen_h = dm.heightPixels;
		
		mDirFrozenImages = Utils.appDirectory + mGroupId + "/frozens/";
		
		mImages = new ArrayList<Img>();
		mFrozenImages = new ArrayList<Integer>();
		
		List<Entity> entitiesImages = DataFramework.getInstance().getEntityList("images", "group_id="+mGroupId, "");
    	
    	for (int i=0; i<entitiesImages.size(); i++) {
    		Entity ent = entitiesImages.get(i);
    		Img img = new Img();
    		img.id = ent.getId();
    		img.basename = ent.getString("basename");
    		img.name = ent.getString("name");
    		img.filename = ent.getString("file");
    		//img.image = getResizedBitmap(BitmapFactory.decodeFile(ent.getString("file")), 48,48);
    		
    		mImages.add(img);
    	}
    	
    	List<Entity> entitiesFrozens = DataFramework.getInstance().getEntityList("frozens", "group_id="+mGroupId, "posy asc");
    	
    	for (int i=0; i<entitiesFrozens.size(); i++) {
    		Entity ent = entitiesFrozens.get(i);
    		mFrozenImages.add(Integer.parseInt(ent.getValue("posy").toString()));
    	}
   	
    	setContentView(R.layout.mix);
    	
    	createImages();
        
    }
        
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);
        menu.add(0, SHARE_ID, 0,  R.string.share)
			.setIcon(android.R.drawable.ic_menu_share);
        menu.add(0, BACK_ID, 0,  R.string.back)
			.setIcon(android.R.drawable.ic_menu_revert);
        return true;
    }
    
    @Override
    public boolean onMenuItemSelected(int featureId, MenuItem item) {
        switch(item.getItemId()) {
        case SHARE_ID:
        	Bitmap outBitmap = Bitmap.createBitmap(screen_w, screen_h, Bitmap.Config.RGB_565);
        	
        	Canvas c = new Canvas(outBitmap);
        	c.drawColor(Color.BLACK);
        	
        	for (int i=0; i<mGalleries.size(); i++) {
        		String img = mGalleries.get(i).getSelectedItem().toString();
        		Bitmap bmp = BitmapFactory.decodeFile(img);
        		int pos = 0;
        		if (i!=0) {
        			pos = mFrozenImages.get(i-1);
        		}
        		c.drawBitmap(bmp, 0, pos, null);
        	}
        	
        	String auxFile = Utils.appDirectory + "aux_share.png";

        	FileOutputStream out;
			try {
				out = new FileOutputStream(auxFile);
				outBitmap.compress(Bitmap.CompressFormat.PNG, 100, out);
			} catch (FileNotFoundException e) {
				e.printStackTrace();
			}
			
			outBitmap.recycle();
			outBitmap = null;	
			
			Intent msg=new Intent(Intent.ACTION_SEND);
			msg.setType("image/png");
			msg.putExtra(Intent.EXTRA_STREAM, Uri.parse("file://"+auxFile));
            startActivity(Intent.createChooser(msg, getString(R.string.share)));
        	
        	return true;
        case BACK_ID:
        	setResult(RESULT_OK);
        	finish();
        	return true;
        }
       
        return super.onMenuItemSelected(featureId, item);
    }
    
	@Override
	protected void onDestroy() {
		super.onDestroy();
		DataFramework.getInstance().close();
	}

	/*
	 * 
	 * TASKS PARA CREAR IMAGENES 
	 * 
	 */
	
    private AsyncTask<Void, Void, Void> createImagesTask;
    
    public void createImages() {
		progressDialog = ProgressDialog.show(
				this,
				getResources().getString(R.string.loading_create_images),
				getResources().getString(R.string.loading_create_images_desc)
		);
		
		progressDialog.setCancelable(true);
		progressDialog.setOnCancelListener(new OnCancelListener() {

			@Override
			public void onCancel(DialogInterface arg0) {
				if (createImagesTask!=null) createImagesTask.cancel(true);
			}
			
		});
		
		createImagesTask = new CropImagesAsyncTask(this, mFrozenImages, mImages, mDirFrozenImages).execute();
    }
	
	@Override
	public void cropImagesLoading() {
		
	}

	@Override
	public void cropImagesCancelled() {
		
	}

	@Override
	public void cropImagesLoaded(Void r) {
		progressDialog.dismiss();
		
    	LinearLayout mainPanel = (LinearLayout)this.findViewById(R.id.root);    	

    	List<Entity> entitiesFrozens = DataFramework.getInstance().getEntityList("frozens", "group_id="+mGroupId, "posy asc");
    	
    	for (int i=0; i<=entitiesFrozens.size(); i++) {
    		Gallery g = new Gallery(this);
    		g.setPadding(0, 0, 0, 0);
    		g.setSpacing(0);
    		    		
    		ArrayList<String> images = new ArrayList<String>();
    		
    		for (int j=0; j<mImages.size(); j++) {
    			Img img = mImages.get(j);
    			images.add(mDirFrozenImages+img.getFrozenFile(i));
    			
    		}
    		
    		ImageAdapter imageAdapter = new ImageAdapter(this, images);
    		
    		g.setAdapter(imageAdapter);
    		
    		mGalleries.add(g);
    		
    		mainPanel.addView(g);    	
    	}
	}
	
}
