package com.javielinux.facemix;

import java.io.IOException;
import java.util.List;

import org.xmlpull.v1.XmlPullParserException;

import utils.Utils;
import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.view.View.OnClickListener;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.LinearLayout.LayoutParams;

import com.android.dataframework.DataFramework;
import com.android.dataframework.Entity;

public class PrepareMix extends Activity {
	
	private static final int MIX_ID = Menu.FIRST;
	private static final int CLEAR_ID = Menu.FIRST + 1;
	
	private String mImgPath = "";
	private int mScreenWidth = 0; 
	private PrepareMixView mImgMix;
	
	private long mGroupId = 1;
	
	private int mPosImage = 0;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        requestWindowFeature(Window.FEATURE_NO_TITLE);  
        getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN,   
                                WindowManager.LayoutParams.FLAG_FULLSCREEN); 
        
        if (savedInstanceState != null) {
			if (savedInstanceState.containsKey("group")) mGroupId = savedInstanceState.getLong("group");
		} else {
			Bundle extras = getIntent().getExtras();  
			if (extras != null) {
				mGroupId = (extras.containsKey("group")) ? extras.getLong("group") : 1;
			} else {
				mGroupId = 1;
			}
		}
        
        try {
			DataFramework.getInstance().open(this, Utils.appPackage);
		} catch (XmlPullParserException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		DisplayMetrics dm = new DisplayMetrics(); 
        getWindowManager().getDefaultDisplay().getMetrics(dm); 
        mScreenWidth = dm.widthPixels; 
		
		List<Entity> entities = DataFramework.getInstance().getEntityList("images", "group_id="+mGroupId, "");
		
		if (entities.size()<=1) {
			Utils.showMessage(this, this.getString(R.string.msg_one_photo));
			setResult(RESULT_OK);
	        finish();
		} else {
			mImgPath = entities.get(mPosImage).getString("file");
		}
		
		FrameLayout fr = new FrameLayout(this);
		
		mImgMix = new PrepareMixView(this, mImgPath, mScreenWidth);
		
		List<Entity> entitiesFrozens = DataFramework.getInstance().getEntityList("frozens", "group_id="+mGroupId, "");
    	
    	for (int i=0; i<entitiesFrozens.size(); i++) {
    		Entity ent = entitiesFrozens.get(i);
    		mImgMix.addFrozen(Integer.parseInt(ent.getValue("posy").toString()));
    	}
        
    	fr.addView(mImgMix);
    	
    	LinearLayout ll = new LinearLayout(this);
    	
    	ImageView btLeft = new ImageView(this);
    	btLeft.setImageResource(R.drawable.btn_left);
    	btLeft.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				previousPhoto();
			}
    		
    	});
    	
    	ll.addView(btLeft);
    	
    	TextView t = new TextView(this);
    	
    	LayoutParams lp = new LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT);
    	lp.weight = 1;
    	
    	ll.addView(t, lp);
    	
    	
    	ImageView btRight = new ImageView(this);
    	btRight.setImageResource(R.drawable.btn_right);
    	btRight.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				nextPhoto();
			}
    		
    	});
    	
    	ll.addView(btRight);
    	
    	fr.addView(ll);
    	
        setContentView(fr);

        
    }
    
    private void nextPhoto() {
		List<Entity> entities = DataFramework.getInstance().getEntityList("images", "group_id="+mGroupId, "");
		
		if (mPosImage<entities.size()-1) {
			mPosImage++;
		} else {
			mPosImage = 0;
		}
		
		mImgPath = entities.get(mPosImage).getString("file");
		
		mImgMix.setFile(mImgPath);
		
		mImgMix.invalidate();
		
    }
    
    private void previousPhoto() {
		List<Entity> entities = DataFramework.getInstance().getEntityList("images", "group_id="+mGroupId, "");
		
		if (mPosImage>0) {
			mPosImage--;
		} else {
			mPosImage = entities.size()-1;
		}
		
		mImgPath = entities.get(mPosImage).getString("file");
		
		mImgMix.setFile(mImgPath);
		
		mImgMix.invalidate();
		
    }

    @Override
    public boolean onTouchEvent(MotionEvent event) {
    	if ( (event.getAction() == MotionEvent.ACTION_DOWN) || (event.getAction() == MotionEvent.ACTION_MOVE) ) {
    		mImgMix.setPosYAuxLine((int)event.getY());
    		mImgMix.drawAuxLine(true);
    	}
    	
    	if (event.getAction() == MotionEvent.ACTION_UP) {
    		if (mImgMix.isDrawAuxLine()) {
    			mImgMix.addFrozen((int)event.getY());
    			mImgMix.drawAuxLine(false);
    		}
    	}
    	
    	mImgMix.invalidate();
    	
    	return true;
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);
        menu.add(0, MIX_ID, 0,  R.string.mix)
    		.setIcon(android.R.drawable.ic_menu_crop);
        menu.add(0, CLEAR_ID, 0,  R.string.clear)
			.setIcon(android.R.drawable.ic_menu_revert);
        return true;
    }
    
    @Override
    public boolean onMenuItemSelected(int featureId, MenuItem item) {
        switch(item.getItemId()) {
        case CLEAR_ID:
        	DataFramework.getInstance().getDB().execSQL("DELETE FROM frozens WHERE group_id = " + mGroupId);
        	mImgMix.clearFrozenImages();
        	mImgMix.invalidate();
            return true;
        case MIX_ID:
        	goToMix();
            return true;
        }
       
        return super.onMenuItemSelected(featureId, item);
    }
    
    public void goToMix() {
    	DataFramework.getInstance().getDB().execSQL("DELETE FROM frozens WHERE group_id = " + mGroupId);
    	List<Integer> frozenImages = mImgMix.getFrozenImages();

    	for (int i=0; i<frozenImages.size(); i++) {
    		Entity ent = new Entity("frozens");
    		ent.setValue("posy", frozenImages.get(i));
    		ent.setValue("group_id", mGroupId);
    		ent.save();
    	}
    	Intent i = new Intent(this, Mix.class);
    	i.putExtra("group", mGroupId);
        startActivity(i);
    }    
    
	@Override
	protected void onDestroy() {
		super.onDestroy();
		DataFramework.getInstance().close();
	}
    
}
