package com.javielinux.facemix;

import java.util.ArrayList;
import java.util.List;

import utils.Utils;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.DashPathEffect;
import android.graphics.Paint;
import android.view.View;

public class PrepareMixView extends View {
	
	private String mFilename = "";
	private Bitmap mBitmap = null; 
	
	private Bitmap mBitmapScissors = null; 
	
	private int mScreenWidth = 0; 
	
	private boolean mDrawAuxLine = false;
	private int mPosYAuxLine = 0;
	private Paint mPaintAuxLine;
	private Paint mPaintLine;
	
	private List<Integer> mFrozenImages;
	
    public PrepareMixView(Context context, String file, int screenWidth) {
        super(context);
        setFocusable(true);
        this.mScreenWidth = screenWidth;
        this.mFilename = file;
        this.mBitmap = BitmapFactory.decodeFile(mFilename);
        
        mBitmapScissors = BitmapFactory.decodeResource(this.getResources(), R.drawable.scissors);
        
        mFrozenImages = new ArrayList<Integer>();
        
        mPaintLine = new Paint();
        mPaintLine.setAntiAlias(true);
        mPaintLine.setColor(Color.BLUE);
        mPaintLine.setStrokeWidth(2);
        mPaintLine.setPathEffect(new DashPathEffect(new float[] { 15, 5, 8, 5 }, 1));
        
        mPaintAuxLine = new Paint();
        mPaintAuxLine.setAntiAlias(true);
        mPaintAuxLine.setColor(Color.RED);
        mPaintAuxLine.setStrokeWidth(2);
        
                
    }
    
    public void setFile(String file) {
    	this.mFilename = file;
    	this.mBitmap = Utils.getBitmap(mFilename);
    }
    
    @Override protected void onDraw(Canvas canvas) {
        canvas.drawColor(0xFFFFFFFF);
        if (mBitmap != null) canvas.drawBitmap(mBitmap, (mScreenWidth/2)-(mBitmap.getWidth()/2), 0, null);
        if (mDrawAuxLine) {
        	canvas.drawLine(0, mPosYAuxLine, mScreenWidth, mPosYAuxLine, mPaintAuxLine);
        	canvas.drawBitmap(mBitmapScissors, 0, mPosYAuxLine-(mBitmapScissors.getHeight()/2), null);
        }
        
        for (int i=0; i<mFrozenImages.size(); i++) {
        	canvas.drawLine(0, mFrozenImages.get(i), mScreenWidth, mFrozenImages.get(i), mPaintLine);
        }
        
    }
    
    public void drawAuxLine(boolean aux) {
    	mDrawAuxLine = aux;
    }
    
    public boolean isDrawAuxLine() {
    	return mDrawAuxLine;
    }
    
    public void setPosYAuxLine(int aux) {
    	mPosYAuxLine = aux;
    }
    
    public void addFrozen(int y) {
    	mFrozenImages.add(y);
    }
    
    public List<Integer> getFrozenImages() {
    	return mFrozenImages;
    }
    
    public void clearFrozenImages() {
    	mFrozenImages.clear();
    }
}
