package tasks;

import info.Img;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.util.List;

import utils.Utils;
import android.graphics.Bitmap;
import android.os.AsyncTask;

public class CropImagesAsyncTask extends AsyncTask<Void, Void, Void> {

	public interface CropImagesAsyncTaskResponder {
		public void cropImagesLoading();
		public void cropImagesCancelled();
		public void cropImagesLoaded(Void r);
	}

	private CropImagesAsyncTaskResponder responder;
	private List<Integer> mFrozenImages;
	private List<Img> mImages; 
	private String mDirFrozenImages = "";

	public CropImagesAsyncTask(CropImagesAsyncTaskResponder responder, List<Integer> mFrozenImages, 
			List<Img> mImages, String mDirFrozenImages) {
		this.responder = responder;
		this.mFrozenImages = mFrozenImages;
		this.mImages = mImages;
		this.mDirFrozenImages = mDirFrozenImages;
	}

	@Override
	protected Void doInBackground(Void... args) {
		createFrozenImages();
		return null;
	}
	
    public void createFrozenImages() {
    	
    	try {
    		
    		if (!Utils.createDirectory(mDirFrozenImages)) {
    			File dir = new File(mDirFrozenImages);
    			String[] ls = dir.list();
    			for (int i=0; i<ls.length; i++) {
    				if ( (!ls[i].equals(".")) && (!ls[i].equals("..")) ) {
    					File f = new File(mDirFrozenImages+ls[i].toString());
    					if (f.exists()) f.delete();
    				}
    			}
    		}

    	} catch (Exception ioe) {
    		ioe.printStackTrace();
    	}
    	
    	for (int i=0; i<mImages.size(); i++) {
    		Img img = mImages.get(i);
    		Bitmap bmp = Utils.getBitmap(img.filename);
    		int w = bmp.getWidth();
    		int h = bmp.getHeight();
    		int aux = 0;

    		//System.out.println("size="+mFrozenImages.size());
    		
    		for (int j=0; j<=mFrozenImages.size(); j++) {
    			int height = 0;
    			if (j==mFrozenImages.size()) {
    				height = h - aux;
    			} else {
    				height = mFrozenImages.get(j) - aux;
    			}
    			
    			//System.out.println("j=" + j +" - aux="+aux+" - h=" + mFrozenImages.get(j) + " - height="+height);
    			
    			Bitmap b = Bitmap.createBitmap(bmp, 0, aux, w, height);
    			String fileDestiny = mDirFrozenImages + img.getFrozenFile(j);
				try {
					FileOutputStream out = new FileOutputStream(fileDestiny);
					b.compress(Bitmap.CompressFormat.PNG, 100, out);
				} catch (FileNotFoundException e) {
					e.printStackTrace();
				}
				if (j!=mFrozenImages.size()) aux = mFrozenImages.get(j);
    		}
    		
    	}
    	
    }

	@Override
	protected void onPreExecute() {
		super.onPreExecute();
		responder.cropImagesLoading();
	}

	@Override
	protected void onCancelled() {
		super.onCancelled();
		responder.cropImagesCancelled();
	}

	@Override
	protected void onPostExecute(Void r) {
		super.onPostExecute(r);
		responder.cropImagesLoaded(r);
	}

}
