package utils;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.channels.FileChannel;

import android.content.Context;
import android.content.SharedPreferences;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;
import android.preference.PreferenceManager;
import android.util.Log;
import android.widget.Toast;

import com.javielinux.facemix.R;

public class Utils {
	
	public static String TAG = "FaceMix";
	
	public static int THRESHOLD = 1000000;
	
	public static int HEIGHT_IMAGE = 72;
	
	public static int TYPE_IMAGE_NORMAL = 0;
	public static int TYPE_IMAGE_EDGE = 1;
	
	static public String appDirectory = "/sdcard/facemix/";
	static public String appPackage = "com.javielinux.facemix";
	static public String auxPhoto = appDirectory + "aux.png";
	public static final int START_PHOTO_ALPHA = 120;
	static public SharedPreferences preference = null;
	static public Context context = null;
	
    public static void showMessage(Context context, String msg) {
	    Toast.makeText(context, 
	    		msg, 
	            Toast.LENGTH_LONG).show();
    }
    
    public static void showShortMessage(Context context, String msg) {
	    Toast.makeText(context, 
	    		msg, 
	            Toast.LENGTH_SHORT).show();
    }
    
	static public void setActivity(Context cnt)
    {
		context = cnt;
		createDirectory(appDirectory);
        PreferenceManager.setDefaultValues(cnt, R.xml.preferences, false);
		preference = PreferenceManager.getDefaultSharedPreferences(cnt);
    }
        
    static public boolean createDirectory(String directory) {
    	try {
    		File dir = new File(directory);
    		if (!dir.exists()) {
    			dir.mkdir();
    			File fileNomedia = new File(directory+".nomedia");
                if (!fileNomedia.exists()) fileNomedia.createNewFile();
    			return true;
    		}
    	} catch (Exception ioe) {
    		ioe.printStackTrace();
    	}
    	return false;
    }
    
   	public static void copy(String source, String destiny) throws IOException {
   		try
    	{
   			System.out.println(source +  " --> " + destiny);
	    	FileInputStream fis = new FileInputStream(source);
	    	FileOutputStream fos = new FileOutputStream(destiny);
	    	FileChannel channelSource = fis.getChannel();
	    	FileChannel channelDestiny = fos.getChannel();
	    	channelSource.transferTo(0, channelSource.size(), channelDestiny);
	    	fis.close();
	    	fos.close();
    	}
    	catch(Exception e)
    	{
    		System.out.println("ERROR: " + e.getMessage());
    		Log.e("Andando: ", e.getClass().getName());
    	}
    }
   	
   	public static String getName(String filename) {
   		String[] ar = filename.split("/");
   		return ar[ar.length-1];
   	}
   	
   	public static void rotateImage(String file, float rotate) {
   		Bitmap bitmapOrg = BitmapFactory.decodeFile(file);

   		int width = bitmapOrg.getWidth();
   		int height = bitmapOrg.getHeight();

   		Matrix matrix = new Matrix();
   		matrix.postRotate(rotate);

   		Bitmap rotateBitmap = Bitmap.createBitmap(bitmapOrg, 0, 0, width, height, matrix, true);
   		
   		bitmapOrg.recycle();
   		bitmapOrg = null;
   		
   		try {
			FileOutputStream out = new FileOutputStream(file);
			rotateBitmap.compress(Bitmap.CompressFormat.PNG, 90, out);
		} catch (Exception e) {
			e.printStackTrace();
		}
   	}
   	
   	public static Bitmap getRotateBitmap(Bitmap bitmap, float rotate) {

   		int width = bitmap.getWidth();
   		int height = bitmap.getHeight();

   		Matrix matrix = new Matrix();
   		matrix.postRotate(rotate);

   		Bitmap rotateBitmap = Bitmap.createBitmap(bitmap, 0, 0, width, height, matrix, true);
   		
   		return rotateBitmap;
   	}
   	
    public static Bitmap edgeFinder(String file, int threshold) {
    	int px = 0, cx = 0, nx = 0, ly = 0, val = 0, y = 0, x = 0, y_width = 0;
    	
    	Bitmap bmp = BitmapFactory.decodeFile(file);
    	
    	int width = bmp.getWidth();
        int height = bmp.getHeight();
    	
    	Bitmap out = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
    	
    	int[] pixels = new int[width*height];
    	bmp.getPixels(pixels, 0, width, 0, 0, width, height);
    	
    	for (y = 1; y < height-1; y++) {

    		y_width = y*width;

    		px = pixels[y_width]/2;
    		cx = pixels[y_width+1]/2;

    		for (x = 1; x < width-1; x++) {
    			nx = pixels[y_width+x+1]/2; // next x

    			ly = (pixels[(y-1)*width+x]/2) - (pixels[(y+1)*width+x]/2);
    			val = Math.abs(px - nx) + Math.abs(ly);
    			if(val > threshold) {
    				out.setPixel(x, y, Color.BLACK);
    			}

    			px = cx;
    			cx = nx;
    		}
    	}
    	
    	bmp.recycle();
    	bmp = null;

    	return out;
    }
    
	static public Bitmap getBitmapFromFile(String file, int height, boolean crop, int roundPixels) {
		File f = new File(file);
		if (f.exists()) {
			try {
				Options opt = new Options();
				opt.inSampleSize = 2;
				Bitmap bm = BitmapFactory.decodeFile(file, opt);
				
				if (crop) {
					
					Bitmap b = null;
					
					if (bm.getWidth()> bm.getHeight()) {
						int x = (bm.getWidth() - bm.getHeight())/2;
						b = Bitmap.createBitmap(bm, x, 0, bm.getHeight(), bm.getHeight());	
					} else {
						int y = (bm.getHeight() - bm.getWidth())/2;
						b = Bitmap.createBitmap(bm, 0, y, bm.getWidth(), bm.getWidth());	
					}
					
					if (roundPixels>0) {
						return getRoundedCornerBitmap(Bitmap.createScaledBitmap(b, height, height, true), roundPixels);
					} else {
						return Bitmap.createScaledBitmap(b, height, height, true);
					}
				} else {
					int width = (height * bm.getWidth()) / bm.getHeight();
					if (roundPixels>0) {
						return getRoundedCornerBitmap(Bitmap.createScaledBitmap(bm, width, height, true), roundPixels);
					} else {
						return Bitmap.createScaledBitmap(bm, width, height, true);
					}
				}
			
			} catch (Exception e) {
				e.printStackTrace();
			}
		} else {
			Log.d(TAG, "El archivo no existe: " + file);
		}
		return null;
    }

	public static Bitmap getRoundedCornerBitmap(Bitmap bitmap, int pixels) {
        Bitmap output = Bitmap.createBitmap(bitmap.getWidth(), bitmap.getHeight(), Config.ARGB_8888);
        Canvas canvas = new Canvas(output);

        final int color = 0xff424242;
        final Paint paint = new Paint();
        final Rect rect = new Rect(0, 0, bitmap.getWidth(), bitmap.getHeight());
        final RectF rectF = new RectF(rect);
        final float roundPx = pixels;

        paint.setAntiAlias(true);
        canvas.drawARGB(0, 0, 0, 0);
        paint.setColor(color);
        canvas.drawRoundRect(rectF, roundPx, roundPx, paint);

        paint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.SRC_IN));
        canvas.drawBitmap(bitmap, rect, rect, paint);

        return output;
    }
	
	public static Bitmap getBitmap(String file) {
		Bitmap bmp = null;
		try {
			bmp = BitmapFactory.decodeFile(file);
    	} catch (Exception e) {
    		try {
    			Options opt = new Options();
    			opt.inSampleSize = 2;
    			bmp = BitmapFactory.decodeFile(file, opt);
    		} catch (Exception e2) {
	    		Options opt = new Options();
	    		opt.inSampleSize = 4;
	    		bmp = BitmapFactory.decodeFile(file, opt);
	    	}
    	}
    	return bmp;
	}
    
}
